@@ -1,3 +1,4 @@
+from gi.repository import GLib
 from gi.repository import Gtk as gtk
 from gi.repository import Atk as atk
 
@@ -14,7 +15,7 @@ COL_APP = 1
 COL_PATH = 2
 _BM_ATTRIBS = ['title', 'app', 'path']
 
-BOOKMARKS_PATH = os.path.join(os.environ['HOME'], '.accerciser')
+BOOKMARKS_PATH = os.path.join(GLib.get_user_config_dir(), 'accerciser')
 BOOKMARKS_FILE = 'bookmarks.xml'
 
 class BookmarkStore(gtk.ListStore):
@@ -334,7 +335,7 @@ class BookmarkStore(gtk.ListStore):
       tv = self._createTreeView(bookmarks_store)
       sw = gtk.ScrolledWindow()
       sw.set_policy(gtk.PolicyType.AUTOMATIC, gtk.PolicyType.AUTOMATIC)
-      sw.set_shadow_type(gtk.ShadowType.IN)
+      sw.set_shadow_type(gtk.ShadowType.IN_)
       sw.add(tv)
       hbox.pack_start(sw, True, True, 0)
       button_vbox = gtk.VBox()
